com.github.jimpil.bass.impl.base2


byte->octetclj

(byte->octet b)

Convert a byte value to a binary octet.

Convert a byte value to a binary octet.
sourceraw docstring

decodeclj

(decode s)

Decodes a binary string back into a byte array, preserving exact leading zeroes (8 bits per byte).

Decodes a binary string back into a byte array,
preserving exact leading zeroes (8 bits per byte).
sourceraw docstring

encodeclj

(encode bs)

Encodes the provided byte-array <bs> in Base2 (i.e. binary). Returns a String whole length is a multiple of 8.

Encodes the provided byte-array <bs> in Base2 (i.e. binary).
Returns a String whole length is a multiple of 8.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries