com.github.jimpil.bass.impl.base32


alphabetclj

source

decodeclj

(decode s)

Decodes a Base32 string into a byte-array.

Decodes a Base32 string into a byte-array.
sourceraw docstring

encodeclj

(encode bs)

Encodes a byte-array, or ByteBuffer into a standard Base32 string.

Encodes a byte-array, or ByteBuffer
into a standard Base32 string.
sourceraw docstring

index-lookupclj

source

pad-rightclj

(pad-right characters)

Base32 always operates in blocks of 40 bits (5 bytes), which cleanly maps to 8 alphanumeric characters. If data falls short of a 5-byte boundary, it must be padded with '=' until the block length is a multiple of 8.

Base32 always operates in blocks of 40 bits (5 bytes),
which cleanly maps to 8 alphanumeric characters.
If data falls short of a 5-byte boundary, it must be padded
with '=' until the block length is a multiple of 8.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries