Clojure only.

com.github.jimpil.bass.impl.base8


decodeclj

(decode s)

Decodes an octal string back into a byte array, preserving exact leading zeroes (3 octal chars per byte).

Decodes an octal string back into a byte array,
preserving exact leading zeroes (3 octal chars per byte).
sourceraw docstring

encodeclj

(encode bs)

Encodes the provided byte-array <bs> in Base8 (i.e. octal). Returns a String whole length is a multiple of 3.

Encodes the provided byte-array <bs> in Base8 (i.e. octal).
Returns a String whole length is a multiple of 3.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries