(byte->octet b)Convert a byte value to a binary octet.
Convert a byte value to a binary octet.
(decode s)Decodes a binary string back into a byte array, preserving exact leading zeroes (8 bits per byte).
Decodes a binary string back into a byte array, preserving exact leading zeroes (8 bits per byte).
(encode bs)Encodes the provided byte-array <bs> in Base2 (i.e. binary). Returns a String whole length is a multiple of 8.
Encodes the provided byte-array <bs> in Base2 (i.e. binary). Returns a String whole length is a multiple of 8.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |