(decode s)Decodes a Base32 string into a byte-array.
Decodes a Base32 string into a byte-array.
(encode bs)Encodes a byte-array, or ByteBuffer into a standard Base32 string.
Encodes a byte-array, or ByteBuffer into a standard Base32 string.
(pad-right characters)Base32 always operates in blocks of 40 bits (5 bytes), which cleanly maps to 8 alphanumeric characters. If data falls short of a 5-byte boundary, it must be padded with '=' until the block length is a multiple of 8.
Base32 always operates in blocks of 40 bits (5 bytes), which cleanly maps to 8 alphanumeric characters. If data falls short of a 5-byte boundary, it must be padded with '=' until the block length is a multiple of 8.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |