(decode s)Decodes an octal string back into a byte array, preserving exact leading zeroes (3 octal chars per byte).
Decodes an octal string back into a byte array, preserving exact leading zeroes (3 octal chars per byte).
(encode bs)Encodes the provided byte-array <bs> in Base8 (i.e. octal). Returns a String whole length is a multiple of 3.
Encodes the provided byte-array <bs> in Base8 (i.e. octal). Returns a String whole length is a multiple of 3.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |